
# Type: metamodel_version


Version of the metamodel used to load the schema

URI: [meta:metamodel_version](https://w3id.org/biolink/biolinkml/meta/metamodel_version)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) ->  <sub>OPT</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | owl |

